@@ -115,13 +115,12 @@ class PeUser(BaseModel):
         for user in users_dicts:
             if user["id"] in contracts_dict:
                 user["contract"] = contracts_dict[user["id"]]
-                pprint(user)
-
                 u = cls(**user)
                 users.append(u)
+                logger.debug(f"User created {u.name}")
             else:
                 pass
-                # logger.warning(f"User withough employment contract {user['name']}")
+                logger.warning(f"User withough employment contract {user['name']}")
 
         users = sorted(users, key=lambda user: (getattr(user.contract, sort_key), user.name))
         cls.add_index(users)
